@@ -1,4 +1,4 @@
 test_that("Spark Integ works", {
-  sc <- test_spark_connect()
+  sc <- use_test_spark_connect()
   expect_true(spark_integ_test_skip(sc, "test"))
 })
